.. FlightplanDB-python documentation master file, created by
   sphinx-quickstart on Wed Mar 10 18:01:47 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to FlightplanDB-py's documentation!
===============================================

Welcome
------------------
If you're new, check out the :doc:`user/introduction` or :doc:`user/quickstart` sections.

.. toctree::
   :maxdepth: 4
   :caption: Docs

   user/userdocs

   api/main



Indices and tables
------------------

* :ref:`genindex`
